@@ -29,6 +29,8 @@ var gAdvancedPane = {
     this.updateModeItems();
 //@line 68 "/builds/slave/mozilla-1.9.2-linux64-nightly/build/browser/components/preferences/advanced.js"
     this.updateOfflineApps();
+//@line 70 "/builds/slave/mozilla-1.9.2-linux64-nightly/build/browser/components/preferences/advanced.js"
+    this.initSubmitCrashes();
 //@line 72 "/builds/slave/mozilla-1.9.2-linux64-nightly/build/browser/components/preferences/advanced.js"
   },
 
